@@ -1,9 +1,10 @@
-# Copyright (c) 2015,2016,2017 MetPy Developers.
+# Copyright (c) 2015,2016,2017,2018 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 r"""This module contains a variety of meteorological calculations."""
 
 from .basic import *  # noqa: F403
+from .cross_sections import *  # noqa: F403
 from .indices import *  # noqa: F403
 from .kinematics import *  # noqa: F403
 from .thermo import *  # noqa: F403
@@ -11,6 +12,7 @@ from .tools import *  # noqa: F403
 from .turbulence import *  # noqa: F403
 
 __all__ = basic.__all__[:]  # pylint: disable=undefined-variable
+__all__.extend(cross_sections.__all__)  # pylint: disable=undefined-variable
 __all__.extend(indices.__all__)  # pylint: disable=undefined-variable
 __all__.extend(kinematics.__all__)  # pylint: disable=undefined-variable
 __all__.extend(thermo.__all__)  # pylint: disable=undefined-variable
