@@ -1,4 +1,4 @@
-# Copyright (c) 2015,2016 MetPy Developers.
+# Copyright (c) 2015,2016,2018 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 r"""Collection of utilities for testing.
@@ -8,12 +8,15 @@ This includes:
 * code for testing matplotlib figures
 """
 
+from __future__ import absolute_import
+
 import numpy as np
 import numpy.testing
 from pint import DimensionalityError
 import pytest
+import xarray as xr
 
-from metpy.calc import get_wind_components
+from metpy.calc import wind_components
 from metpy.cbook import get_test_data
 from .units import units
 
@@ -33,14 +36,14 @@ def get_upper_air_data(date, station):
         dict : upper air data
 
     """
-    soudning_key = '{0:%Y-%m-%dT%HZ}_{1:}'.format(date, station)
+    sounding_key = '{0:%Y-%m-%dT%HZ}_{1:}'.format(date, station)
     sounding_files = {'2016-05-22T00Z_DDC': 'may22_sounding.txt',
                       '2013-01-20T12Z_OUN': 'jan20_sounding.txt',
                       '1999-05-04T00Z_OUN': 'may4_sounding.txt',
                       '2002-11-11T00Z_BNA': 'nov11_sounding.txt',
                       '2010-12-09T12Z_BOI': 'dec9_sounding.txt'}
 
-    fname = sounding_files[soudning_key]
+    fname = sounding_files[sounding_key]
     fobj = get_test_data(fname)
 
     def to_float(s):
@@ -74,7 +77,7 @@ def get_upper_air_data(date, station):
     direc = direc * units.degrees
     spd = spd * units.knots
 
-    u, v = get_wind_components(spd, direc)
+    u, v = wind_components(spd, direc)
 
     return {'pressure': p, 'height': z, 'temperature': t,
             'dewpoint': td, 'direction': direc, 'speed': spd, 'u_wind': u, 'v_wind': v}
@@ -163,6 +166,13 @@ def assert_array_equal(actual, desired):
     numpy.testing.assert_array_equal(actual, desired)
 
 
+def assert_xarray_allclose(actual, desired):
+    """Check that the xarrays are almost equal, including coordinates and attributes."""
+    xr.testing.assert_allclose(actual, desired)
+    assert desired.metpy.coordinates_identical(actual)
+    assert desired.attrs == actual.attrs
+
+
 @pytest.fixture(scope='module', autouse=True)
 def set_agg_backend():
     """Fixture to ensure the Agg backend is active."""
